@@ -355,8 +355,11 @@ class CSARPackage(package_base.PackageBase):
         ]
 
         destroy = [
+            {YAQL('$environment'): YAQL(
+                "$.find('io.murano.Environment').require()"
+            )},
             {YAQL('$stack'): YAQL(
-                "new('io.murano.system.HeatStack', "
+                "new('io.murano.system.HeatStack', $environment, "
                 "name => $.getAttr(generatedHeatStackName))")},
 
             YAQL('$stack.delete()')
@@ -494,12 +497,17 @@ class CSARPackage(package_base.PackageBase):
         return translated
 
     @staticmethod
-    def _generate_application_ui(groups, type_name):
+    def _generate_application_ui(groups, type_name, package_name=None,
+                                 package_version=None):
         app = {
             '?': {
                 'type': type_name
             }
         }
+        if package_name:
+            app['?']['package'] = package_name
+        if package_version:
+            app['?']['classVersion'] = package_version
 
         for i, record in enumerate(groups):
             section = app.setdefault('templateParameters', {})
@@ -522,7 +530,7 @@ class CSARPackage(package_base.PackageBase):
         translated = {
             'Version': 2.2,
             'Application': CSARPackage._generate_application_ui(
-                groups, self.full_name),
+                groups, self.full_name, self.full_name, str(self.version)),
             'Forms': forms
         }
         return yaml.dump(translated, Dumper=Dumper, default_style='"')
