@@ -16,6 +16,7 @@
 
 from oslo_config import cfg
 import oslo_messaging as messaging
+from oslo_utils import timeutils
 import six
 
 from murano.common import uuidutils
@@ -47,7 +48,8 @@ class StatusReporter(object):
             'text': msg,
             'details': details,
             'level': level,
-            'environment_id': self._environment_id
+            'environment_id': self._environment_id,
+            'timestamp': timeutils.isotime()
         }
         self._notifier.info({}, 'murano.report_notification', body)
 
